/* eslint-disable @next/next/no-img-element */
import { capitalizeFirstLetter } from "@/common/string-utils";
import { SkinPart } from "mcutils-library";
import Link from "next/link";
import { ReactElement } from "react";
import { Button } from "../ui/button";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "../ui/dialog";

type SkinPartImageProps = {
  /**
   * The player's name.
   */
  playerName: string;

  /**
   * The skin part.
   */
  part: SkinPart;

  /**
   * The URL to the skin part.
   */
  url: string;
};

export function SkinPartImage({ playerName, part, url }: SkinPartImageProps): ReactElement {
  return (
    <Dialog>
      <DialogTrigger asChild>
        <img className="h-[64px]" src={url} alt={`The player's ${part}`} loading="lazy" />
      </DialogTrigger>
      <DialogContent className="w-fit min-w-72 h-fit">
        <DialogHeader>
          <DialogTitle>
            {playerName}&apos;s {capitalizeFirstLetter(part)}
          </DialogTitle>
          <DialogDescription>See the skin part below.</DialogDescription>
        </DialogHeader>
        <div className="flex items-center flex-col w-full">
          <img className="h-[256px]" src={url} alt={`The player's ${part}`} loading="lazy" />
        </div>
        <DialogFooter>
          <Link href={url}>
            <Button>Open in new tab</Button>
          </Link>
        </DialogFooter>
      </DialogContent>
    </Dialog>
  );
}
